gc3libs.application.rosetta — gc3pie development (SVN $Revision$) documentation

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »

# gc3libs.application.rosetta

Specialized support for computational jobs running programs in the Rosetta suite.

class `gc3libs.application.rosetta.` `RosettaApplication`(application, application_release, inputs, outputs=[], flags_file=None, database=None, arguments=[], **extra_args)

  Specialized Application object to submit one run of a single application in the Rosetta suite.

  Required parameters for construction:

  > - application: name of the Rosetta application to call (e.g., “docking_protocol” or “relax”)
  > - inputs: a dict instance, keys are Rosetta `-in:file:*` options, values are the (local) path names of the corresponding files. (Example: `inputs={"-in:file:s":"1brs.pdb"}`)
  > - outputs: list of output file names to fetch after Rosetta has finished running.

  Optional parameters:

  > - flags_file: path to a local file containing additional flags for controlling Rosetta invocation; if None, a local configuration file will be used.
  > - database: (local) path to the Rosetta DB; if this is not specified, then it is assumed that the correct location will be available at the remote execution site as environment variable `ROSETTA_DB_LOCATION`
  > - arguments: If present, they will be appended to the Rosetta application command line.

  `terminated`()

    Extract output files from the tar archive created by the ‘rosetta.sh’ script.

class `gc3libs.application.rosetta.` `RosettaDockingApplication`(pdb_file_path, native_file_path=None, number_of_decoys_to_create=1, flags_file=None, application_release='3.1', **extra_args)

  Specialized Application class for executing a single run of the Rosetta “docking_protocol” application.

  Currently used in the gdocking app.

### Navigation

- index
- modules |
- next |
- previous |
- gc3pie development (SVN $Revision$) documentation »
- Programmer Documentation »
- GC3Libs programming API »